﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = True
    config.window_icon = "icon.png"

    ## These control the width and height of the screen.

    config.screen_width = 640
    config.screen_height = 480

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"The Outbreak: Day Zero"

    # These control the name and version of the game, that are reported
    # with tracebacks and other debugging logs.
    config.name = "The Outbreak: Day Zero"
    config.version = "1.0"

    #########################################
    # Layouts
    
    ## This enables the use of an in-game menu that is made out of
    ## buttons.
    layout.one_column_preferences()
    layout.button_menu()

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.
    theme.tv(

        ## The color of an idle widget face.
        widget = "#880A0A",

        ## The color of a focused widget face.
        widget_hover = "#AB1515",

        ## The color of the text in a widget.
        widget_text = "#FFFFFF",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#FFFFFF",

        ## The color of a disabled widget face. 
        disabled = "#404040",

        ## The color of disabled widget text.
        disabled_text = "#999999",

        ## The color of informational labels.
        label = "#ffffff",

        ## The color of a frame containing widgets.
        frame = "#640000",

        ## If this is True, in-game menus are placed in the center
        ## the screen. If False, they are placed inside a window
        ## at the bottom of the screen.
        button_menu = True,

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = False,

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "images/menu.png",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "images/gmenu.png",

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.            
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.

    #style.window.background = Frame("frame.png", 12, 12)

    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    #style.window.left_margin = 15
    #style.window.right_margin = 15
    #style.window.top_margin = 15
    #style.window.bottom_margin = 15

    ## Padding is space inside the window, where the background is
    ## drawn.

    style.window.left_padding = 15
    style.window.top_padding = 15
    style.window.bottom_padding = 15
    style.window.right_padding = 15

    ## This is the minimum height of the window, including the margins
    ## and padding.

    style.window.yminimum = 158


    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    style.mm_menu_frame.xpos = 1.0
    style.mm_menu_frame.xanchor = 1.0
    style.mm_menu_frame.ypos = 1.0
    style.mm_menu_frame.yanchor = 1.0
    style.mm_menu_frame.right_margin = 10
    style.mm_menu_frame.bottom_margin = 10

    style.mm_button_text.size = 24
    style.mm_button_text.hover_color = "#cc1717"
    style.mm_button_text.xalign = 1.0
    style.mm_button.background = None
    style.mm_menu_frame.background = None

    style.gm_nav_frame.xpos = 1.0
    style.gm_nav_frame.xanchor = 1.0
    style.gm_nav_frame.ypos = 1.0
    style.gm_nav_frame.yanchor = 1.0
    style.gm_nav_frame.right_margin = 10
    style.gm_nav_frame.bottom_margin = 10

    config.main_menu = [
        (u"Start", "start", "True"),
        (u"Load", _intra_jumps("load_screen", "main_game_transition"), "True"),
        (u"Settings", _intra_jumps("preferences_screen", "main_game_transition"), "True"),
        (u"Quit", ui.jumps("_quit"), "True")
        ]

    config.game_menu = [
        ( None, u"Return", ui.jumps("_return"), 'True'),
        ( "preferences", u"Settings", _intra_jumps("preferences_screen", "intra_transition"), 'True' ),
        ( "save", u"Save", _intra_jumps("save_screen", "intra_transition"), 'not main_menu' ),
        ( "load", u"Load", _intra_jumps("load_screen", "intra_transition"), 'True'),
        ( None, u"Main Menu", ui.callsinnewcontext("_main_menu_prompt"), 'not main_menu' ),
        ( None, u"Quit", ui.callsinnewcontext("_quit_prompt"), 'True' ),
        ]

    config.sample_sound = None
    config.sample_voice = None
    config.has_transitions = False
    config.has_cps = False
    config.has_afm = False
    config.has_skipping = False
    config.has_skip_after_choice = False
    config.always_has_joystick = False
    config.has_joystick = False


    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    style.default.font = "Roboto-Regular.ttf"

    ## The default size of text.

    style.default.size = 18
    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.

    style.button.activate_sound = "sfx/tap.ogg"
    style.imagemap.activate_sound = "sfx/tap.ogg"

    ## Sounds that are used when entering and exiting the game menu.

    config.enter_sound = "sfx/tap.ogg"
    config.exit_sound = "sfx/tap.ogg"

    ## A sample sound that can be played to check the sound volume.

    config.sample_sound = None

    ## Music that is played while the user is at the main menu.

    config.main_menu_music = "music/aftermath.ogg"

    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "README.html"
    

    #########################################
    ## Miscellaneous customizations

    ## These let you change the transitions that are used when entering
    ## and exiting the game menu.

    ## Used when entering the game menu from the game.
    config.enter_transition = fade

    ## Used when exiting the game menu to the game.
    config.exit_transition = fade

    ## Used between screens of the game menu.
    config.intra_transition = None

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = fade

    ## Used when returning to the main menu from the game.
    config.game_main_transition = fade

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = fade

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = fade

    ## Used when a game is loaded.
    config.after_load_transition = fade

    ## Used when the window is shown.
    config.window_show_transition = fade

    ## Used when the window is hidden.
    config.window_hide_transition = fade


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "The Outbreak Day Zero"
        
init -1 python hide:
    ## Note: The following two options are only evaluated the first time
    ## a game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?
    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.
    config.default_text_cps = 0
                         
## This section contains information about how to build your project into 
## distribution files.
init python:
    
    ## The name that's used for directories and archive files. For example, if
    ## this is 'mygame-1.0', the windows distribution will be in the
    ## directory 'mygame-1.0-win', in the 'mygame-1.0-win.zip' file.
    build.directory_name = "The Outbreak Day Zero"
    
    ## The name that's uses for executables - the program that users will run
    ## to start the game. For example, if this is 'mygame', then on Windows,
    ## users can click 'mygame.exe' to start the game.
    build.executable_name = "The Outbreak Day Zero"
    
    ## If True, Ren'Py will include update information into packages. This
    ## allows the updater to run.
    build.include_update = False
    
    ## File patterns:
    ## 
    ## The following functions take file patterns. File patterns are case-
    ## insensitive, and matched against the path relative to the base
    ## directory, with and without a leading /. If multiple patterns match,
    ## the first is used.
    ##    
    ##
    ## In a pattern:
    ##
    ## / 
    ##     Is the directory separator.
    ## *
    ##     Matches all characters, except the directory separator.
    ## **
    ##     Matches all characters, including the directory separator.
    ##
    ## For example:
    ##
    ## *.txt
    ##     Matches txt files in the base directory.
    ## game/**.ogg
    ##     Matches ogg files in the game directory or any of its subdirectories.
    ## **.psd
    ##    Matches psd files anywhere in the project.

    ## Classify files as None to exclude them from the built distributions.

    build.classify('**~', None)
    build.classify('**.bak', None)
    build.classify('**/.**', None)
    build.classify('**/#**', None)
    build.classify('**/thumbs.db', None)
    
    ## To archive files, classify them as 'archive'.
    
    # build.classify('game/**.png', 'archive')
    # build.classify('game/**.jpg', 'archive')

    ## Files matching documentation patterns are duplicated in a mac app
    ## build, so they appear in both the app and the zip file.

    build.documentation('*.html')
    build.documentation('*.txt')